<?php
/**
 * The header for our theme.
 *
 * @package Hitoma
 */

?>
<?php
    $meta_description = hitoma_get_text_from_theme_mod_id( 'hitoma-theme_options-meta_description', DEFAULT_META_DESCRIPTION );
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php echo esc_attr( get_bloginfo( 'charset' ) ); ?>">
    <meta name="description" content="<?php echo esc_html( $meta_description ); ?>">
    <meta name="viewport" content="width=device-width,initial-scale=1">
	<?php
        // 投稿ページと固定ページだけを対象に検索結果から非表示にする
        if ( is_page() ) {
            echo '<meta name="robots" content="noindex,nofollow,noarchive">' . "\n";
        }
	?>
    <?php wp_head(); ?>
</head>
<body id="js-page_top">
<?php
    $logo_image    = hitoma_get_image_from_theme_mod_id( 'hitoma-theme_options-logo_image', DEFAULT_LOGO_IMAGE_URL );
    $title         = get_bloginfo( 'name' );
    $tel           = hitoma_get_text_from_theme_mod_id( 'hitoma-theme_options-contact_number_tel', DEFAULT_CONTACT_NUMBER_TEL );
    $fax           = hitoma_get_text_from_theme_mod_id( 'hitoma-theme_options-contact_number_fax', DEFAULT_CONTACT_NUMBER_FAX );
    $contact_text1 = hitoma_get_text_from_theme_mod_id( 'hitoma-theme_options-contact_number_text01', DEFAULT_CONTACT_NUMBER_TEXT1 );
    $contact_text2 = hitoma_get_text_from_theme_mod_id( 'hitoma-theme_options-contact_number_text02', DEFAULT_CONTACT_NUMBER_TEXT2 );

    $has_header_content = $logo_image || $title || $tel !== '' || $fax !== '' || $contact_text1 !== '' || $contact_text2 !== '';
    $has_title_block    = $logo_image || $title !== '';
    $has_contact_block  = $tel !== '' || $fax !== '' || $contact_text1 !== '' || $contact_text2 !== '';
?>
<!-- ヘッダー -->
<?php if ( $has_header_content ) : ?>
    <header>
        <!-- タイトルブロック -->
        <?php if ( $has_title_block ) : ?>
            <div class="title">
                <?php if ( is_page() ) : ?>
                    <!-- Privacy Policyページ --->
                    <?php if ( $logo_image ) : ?>
                        <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
                            <span class="title-logo"><?php echo $logo_image; ?></span>
                        </a>
                    <?php endif; ?>
                    <?php if ( $title !== '' ) : ?>
                        <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
                            <span class="title-text"><?php echo esc_html( $title ); ?></span>
                        </a>
                    <?php endif; ?>
                <?php else : ?>
                    <!-- 通常ページ --->
                    <?php if ( $logo_image ) : ?>
                        <span class="title-logo"><?php echo $logo_image; ?></span>
                    <?php endif; ?>
                    <?php if ( $title !== '' ) : ?>
                        <span class="title-text"><?php echo esc_html( $title ); ?></span>
                    <?php endif; ?>
                <?php endif; ?>
            </div>
        <?php endif; ?>
        <!-- /タイトルブロック -->
        <!-- コンタクトブロック -->
        <?php if ( $has_contact_block ) : ?>
            <div class="contact">
                <?php if ( $tel !== '' || $fax !== '' ) : ?>
                    <div class="contact-number">
                        <?php if ( $tel !== '' ) : ?>
                            <div class="contact-number-tel"><?php echo esc_html( $tel ); ?></div>
                        <?php endif; ?>
                        <?php if ( $fax !== '' ) : ?>
                            <div class="contact-number-tel"><?php echo esc_html( $fax ); ?></div>
                        <?php endif; ?>
                    </div>
                <?php endif; ?>
                <?php if ( $contact_text1 !== '' || $contact_text2 !== '' ) : ?>
                    <div class="contact-text">
                        <?php if ( $contact_text1 !== '' ) : ?>
                            <div class="contact-text-top"><?php echo esc_html( $contact_text1 ); ?></div>
                        <?php endif; ?>
                        <?php if ( $contact_text2 !== '' ) : ?>
                            <div class="contact-text-bottom"><?php echo esc_html( $contact_text2 ); ?></div>
                        <?php endif; ?>
                    </div>
                <?php endif; ?>
            </div>
        <?php endif; ?>
        <!-- /コンタクトブロック -->
    </header>
<?php endif; ?>
<!-- /ヘッダー -->
